@@ -246,6 +246,8 @@ static bool probe_piece(pTHX_ SV *argsv, size_t *argidx, const struct XSParseKey
       if(!probe_piece(aTHX_ argsv, argidx, pieces++, hookdata))
         return FALSE;
 
+      lex_read_space(0);
+
       parse_pieces(aTHX_ argsv, argidx, pieces, hookdata);
       return TRUE;
     }
@@ -291,9 +293,11 @@ static bool probe_piece(pTHX_ SV *argsv, size_t *argidx, const struct XSParseKey
       }
       /* we're now committed */
       THISARG.i = 1;
+      lex_read_space(0);
       if(pieces[2].type)
         parse_pieces(aTHX_ argsv, argidx, pieces + 2, hookdata);
 
+      lex_read_space(0);
       if(!probe_piece(aTHX_ argsv, argidx, pieces + 0, hookdata))
         return TRUE;
 
@@ -301,6 +305,8 @@ static bool probe_piece(pTHX_ SV *argsv, size_t *argidx, const struct XSParseKey
         parse_pieces(aTHX_ argsv, argidx, pieces + 1, hookdata);
         THISARG.i++;
 
+        lex_read_space(0);
+
         if(!probe_piece(aTHX_ argsv, argidx, pieces + 0, hookdata))
           break;
       }
@@ -609,7 +615,11 @@ static void parse_piece(pTHX_ SV *argsv, size_t *argidx, const struct XSParseKey
       if(is_special)
         THISARG.padix = pad_add_name_pvn(SvPVX(varname), SvCUR(varname), 0, NULL, NULL);
       else
-        yycroak("TODO: XS_PARSE_KEYWORD_LEXVAR without LEXVAR_MY");
+#if HAVE_PERL_VERSION(5, 16, 0)
+        THISARG.padix = pad_findmy_pvn(SvPVX(varname), SvCUR(varname), 0);
+#else
+        THISARG.padix = pad_findmy(SvPVX(varname), SvCUR(varname), 0);
+#endif
 
       (*argidx)++;
       return;
@@ -678,6 +688,7 @@ static void parse_piece(pTHX_ SV *argsv, size_t *argidx, const struct XSParseKey
           return;
         THISARG.i++;
         pieces++;
+        lex_read_space(0);
       }
 
       parse_pieces(aTHX_ argsv, argidx, pieces, hookdata);
@@ -689,6 +700,7 @@ static void parse_piece(pTHX_ SV *argsv, size_t *argidx, const struct XSParseKey
       (*argidx)++;
       while(probe_piece(aTHX_ argsv, argidx, piece->u.pieces + 0, hookdata)) {
         THISARG.i++;
+        lex_read_space(0);
         parse_pieces(aTHX_ argsv, argidx, piece->u.pieces + 1, hookdata);
       }
       return;
@@ -708,8 +720,11 @@ static void parse_piece(pTHX_ SV *argsv, size_t *argidx, const struct XSParseKey
         parse_pieces(aTHX_ argsv, argidx, piece->u.pieces + 1, hookdata);
         THISARG.i++;
 
+        lex_read_space(0);
+
         if(!probe_piece(aTHX_ argsv, argidx, piece->u.pieces + 0, hookdata))
           break;
+        lex_read_space(0);
       }
       return;
 
